@@ -34,6 +34,9 @@
 
 #include <QtCore/QTimer>
 
+#ifdef STRIGI_HAS_VERSION_HEADER
+ #include <strigi/strigiconfig.h>
+#endif
 
 Nepomuk2::FileIndexer::FileIndexer( QObject* parent, const QList<QVariant>& )
     : Service( parent )
@@ -79,8 +82,16 @@ Nepomuk2::FileIndexer::FileIndexer( QObject* parent, const QList<QVariant>& )
     m_indexScheduler->setIndexingSpeed( IndexScheduler::SnailPace );
 
     // start initial indexing honoring the hidden config option to disable it
-    if(FileIndexerConfig::self()->isInitialRun() ||
-       !FileIndexerConfig::self()->initialUpdateDisabled()) {
+#ifdef STRIGI_HAS_VERSION_HEADER
+    const QString strigiVersion(Strigi::versionString());
+#else
+    const QString strigiVersion("unknown");
+#endif
+
+    if( ( FileIndexerConfig::self()->isInitialRun() ||
+          FileIndexerConfig::self()->strigiVersion() != strigiVersion )
+        && !FileIndexerConfig::self()->initialUpdateDisabled() )
+    {
         m_indexScheduler->updateAll();
     }
 
@@ -141,6 +152,13 @@ void Nepomuk2::FileIndexer::slotIdleTimerResume()
 void Nepomuk2::FileIndexer::slotIndexingDone()
 {
     FileIndexerConfig::self()->setInitialRun(false);
+
+#ifdef STRIGI_HAS_VERSION_HEADER
+    const QString strigiVersion(Strigi::versionString());
+#else
+    const QString strigiVersion("unknown");
+#endif
+    FileIndexerConfig::self()->setStrigiVersion(strigiVersion);
 }
 
 
