@@ -38,7 +38,6 @@ namespace Nepomuk2 {
     class DataManagementModel;
     class DataManagementAdaptor;
     class ClassAndPropertyTree;
-    class GraphMaintainer;
     class VirtuosoInferenceModel;
 
     /**
@@ -110,8 +109,6 @@ namespace Nepomuk2 {
         Soprano::NRLModel* m_nrlModel;
         const Soprano::Backend* m_backend;
 
-        QPointer<GraphMaintainer> m_graphMaintainer;
-
         // only used during opening
         // ------------------------------------------
         ModelCopyJob* m_modelCopyJob;
